<?php
/*
Plugin Name: WordPress Version Check [k]
Plugin URI: http://wp-plugins.net/plugin/wp-version-monitor-k
Description: Monitors for WordPress version updates and displays version info in the admin screen. Also compatible with <a href="http://somethingunpredictable.com/wp-dash/" target="_blank">WP-Dash plugin</a> (you will find a new dashboard widget which displays the update message.)  This is a kluge of <a href="http://blog.ftwr.co.uk/wordpress/wp-version-check/" target="_blank">P. Westwood's original PJW Wordpress Version Check</a>, to get rid of the HUGE font and blinking text.  Also adds compatibility with <a href="http://www.chaaban.info/wordpress-plugin/motivational-quote/" target="_blank">Motivational Quotes</a> and <a href="http://svn.automattic.com/wordpress/trunk/wp-content/plugins/hello.php" target="_blank">Hello Dolly</a> plugins (by moving their text; any H.D.-based plugin can be easily added). Allegedly compatible with <a href="http://orderedlist.com/wordpress-plugins/wp-tiger-administration/" target="_blank">WP Tiger Admin</a> (not tested by me).  Only tested in WP 2.0.  CSS twiddling probably required for WP 1.x.
Author: Stanton McCandlish (nominally)
Version: 1.0b
Author URI: http://www.McCandlishConsulting.com/
*/ 

/* Installation: Read the readme file and the notes below! */

/*
This is entirely based on this original plugin:

# Plugin Name: PJW Wordpress Version Check
# Plugin URI: http://blog.ftwr.co.uk/wordpress/wp-version-check/
# Description: Monitors for wordpress version updates and displays info in the admin screen.
# Author: Peter Westwood
# Version: 1.00
# Author URI: http://blog.ftwr.co.uk/
*/

/* The VAST majority of this code is Peter Westwood's.  If he changes his
   plugin to use a sane font size and to stop using annoying blinking text,
   I'll be happy to remove my version from distribution. - S.McC. */

/*  Copyright 2006  Stanton McCandlish; most of this code is 
    Copyright 2005  Peter Westwood  (email : peter.westwood@ftwr.co.uk)

    This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* If the placement seems weird to you, try putting a larger number such as
   15px in place of 10px where it says "top: 10px;" here:
				echo "#pjw_update { font-size: 1em; position: absolute; top: 10px; margin: 0; padding: 0; right: 1.5em;}";
   I am not able to test the condition that triggers this line of code (I think
   it is the presence of WP 1.x).  -S.McC.

   If you have some other plugin based on Hello Dolly or Motivational Quotes,
   you can make it compatible by opening it and finding out what id it uses
   for its CSS (e.g. "#foo") and adding that to this code below:
             #motivational, #dolly {
   e.g.:
             #motivational, #dolly, #foo {
   
   WP Tiger Admin users are almost certainly going to have to adjust the CSS
   if they are using this plugin along with Hello Dolly or Mot. Quotes.             
*/

include_once(ABSPATH . WPINC . '/class-IXR.php');

/* Simple class to keep everything private */
class pjw_wp_version_check
{
	//Edit this to get an email when status changes
	var $admin_email = "";

	var $options = array("last_run"=>0,
						 "last_version"=>"",
						 "ixr_response"=>array("class" => "warning", 
					 						   "message" => "Failed to get update information."));
	var $version = 1.00;

	function init()
	{
		add_option('pjw_wp_version_check',$this->options,'Settings for the version check plugin.','yes');
		$this->options = get_option('pjw_wp_version_check');
		/* wp-dash integration */
		if(function_exists('make_widget_available'))
        	make_widget_available('Wordpress Version Check', 'Displays the WP Version Check message.', 'pjw_wp_version_check_');
	}

	function update_and_output_css()
	{
		$this->update_if_required();
		$this->output_css();
	}
	
	function update_if_required()
	{
		global $wp_version;

		if (($this->options["last_run"] + ( 15 * 60)) < time() || $this->options["last_version"] != $wp_version)
		{
			$ixrcli = new IXR_Client('http://sandbox.ftwr.co.uk/xmlrpc/wp.php',false,80,15);
			$ixrcli->useragent =  'IXR';
			$ixrcli->useragent .= ' -- WordPress/'.$wp_version;
			$ixrcli->useragent .= ' -- VC/'.$this->version;
			$ixrcli->useragent .= ' ('.get_bloginfo('url').')';
			
			
			if ($ixrcli->query('wp.get_version_report',$wp_version))
			{
				$ixr_res = $ixrcli->getResponse();
				
				// Ok if the we have an email address do the has_changed check
				if ("" != $this->admin_email) {
					if ($ixr_res["message"] != $this->options["ixr_response"]["message"])
					{
						$title = "[". get_settings('blogname') ."] Message from Version-Check/".$this->version."\n";
						$email =  "Message from Version-Check/".$this->version."\n";
						$email .= "Running at ".get_bloginfo('url')."\n";
						$email .= $ixr_res["message"]."\n";
						$email .= "Previous message was:\n";
						$email .= $this->options["ixr_response"]["message"];

						wp_mail($this->admin_email,$title,$email);
					}
				}
				
				$this->options["ixr_response"] = $ixr_res;
				$this->options["last_run"] = time();
				$this->options["last_version"] = $wp_version;
				update_option('pjw_wp_version_check',$this->options);				
			}
			else
			{
				$this->options["ixr_response"] = array("class"=>"warning", 
								 "message" => "XML-RPC Error:".$ixrcli->getErrorCode().":".$ixrcli->getErrorMessage());
				update_option('pjw_wp_version_check',$this->options);
			}
		}
	}

	//The message
	function output_text() {
		echo "<p id='pjw_update' class='";
		echo $this->options["ixr_response"]["class"];
		echo "' >";
		echo $this->options["ixr_response"]["message"];
		echo "</p>";
	}

	function wp_dash_content($id) {
		//If we are running from wp-dash then we will get called here before the normal update.
		$this->update_if_required();
		
		$content  = "<p class='";
		$content .= $this->options["ixr_response"]["class"];
		$content .= "' >";
		$content .= $this->options["ixr_response"]["message"];
		$content .= "</p>";
		return $content;
	}

	function wp_dash_css($id) {
		return default_widget_css($id) . "#widget$id {font-size:15px;} ";
	}

	//Do we have the Tiger Admin plugin running?
	function is_tiger_admin()
	{
		global $current_plugins;
		if (!empty($current_plugins) &&
		   (in_array("wp-admin-tiger/wp-admin-tiger.php", $current_plugins) || 
		   (in_array("wp-admin-tiger.php", $current_plugins))))
			return TRUE;
		else	
			return FALSE;
	}
	
	// We need some CSS to position the paragraph
	function output_css() {
		if (!$this->is_tiger_admin())
		{
			echo "<style type='text/css'>";
			global $wp_db_version;
			if(0 == $wp_db_version) {
				echo "#pjw_update { font-size: .8em; position: absolute; top: 15px; margin: 0; padding: 0; right: 1.5em;}";
			} else {
				echo "#pjw_update { font-size: .8em; position: absolute; top: 2.5em; right: 1em; }";
			}
			echo "
			.warning { color: orange; }
			.critical { color: red; }
			.info { color: #999999; }
			</style>
			";
            echo "<style type='text/css'>
            #motivational, #dolly {  /* overrides those plugins' defaults */
            font-size: .8em;
            color: #222222;
            top: 1px;
            right: auto;
            left: 10px;
            }
            </style>
            ";

		} else {
		//Alternate Tiger compatible style
		//Props to Mark J (http://txfx.net) for the CSS
		//As seen here: http://blog.ftwr.co.uk/archives/2005/07/09/wordpress-version-check-080/#comment-4271
			echo "
    			<style type=text/css>
	    			#pjw_update { position: fixed; bottom: 3px; z-index: 101; margin: 0; padding: 0; left: 15px; font-size: x-small;}
					.warning { color: orange; }
					.critical { color: red; }
					.info { color: #aaa; }
				</style>
			";
            echo "
              <style type='text/css'>
                #motivational, #dolly {  /* overrides those plugins' defaults */
                position: fixed;
                bottom: 20px; /* this probably needs adjusting! */
                font-size: x-small;
                color: #222222;
                top-auto;
                right: auto;
                left: 10px;
                }
              </style>
            ";
		}

	} // end output_css()
}

/* Initialise ourselves */
$pjw_wp_ver_chk = new pjw_wp_version_check;

/* add some actions */
/* move all code to actions - only run update if it's an admin page - should reduce calls to XML-RPC service */
add_action('plugins_loaded', array(&$pjw_wp_ver_chk,'init'));
add_action('admin_footer', array(&$pjw_wp_ver_chk,'output_text'));
add_action('admin_head', array(&$pjw_wp_ver_chk,'update_and_output_css'));

/* Support functions for wp-dash widget */
function pjw_wp_version_check_content($id){ global $pjw_wp_ver_chk; return $pjw_wp_ver_chk->wp_dash_content($id); }
function pjw_wp_version_check_css($id){ global $pjw_wp_ver_chk; return $pjw_wp_ver_chk->wp_dash_css($id); }
?>
